/**
 * Service for recover
 * @rends TheService
 * @class TheRecoverService
 */
'use strict'

const theDate = require('the-date')
const { TheExpiredError } = require('the-error')
const { TheService } = require('the-service-base')

const { Durations: { ONE_HOUR } } = theDate

class TheRecoverService extends TheService {
  /**
   * Process preparing recover flow
   * @param {Object} config
   * @returns {Promise<Object>}
   */
  async processPrepare (config) {
    const {
      email,
      expireIn = 48 * ONE_HOUR,
    } = config
    const { Profile } = this.resources
    await Profile.assertEmailExists(email)
    const user = await Profile.userWithEmail(email)
    const expireAt = Number(theDate().add(expireIn).toDate())
    const envelop = { expireAt, userId: user.id }
    return { envelop, expireAt, user }
  }

  /**
   * Process password reset
   * @param {Object} config
   * @returns {Promise<{sign: *, user: *}>}
   */
  async processReset (config) {
    const {
      envelop,
      password,
    } = config
    const { Sign, User } = this.resources
    const { expireAt, userId } = envelop
    const isExpired = new Date(Number(expireAt)) < new Date()
    if (isExpired) {
      throw new TheExpiredError('Recovery expired')
    }
    await User.assertUserNotGone(userId)

    const user = await User.one(userId)
    await Sign.setUserPassword(user, password)

    const sign = await Sign.ofUser(user)

    return { sign, user }
  }
}

module.exports = TheRecoverService
