/**
 * Test for TheAccountService.
 * Runs with mocha.
 */
'use strict'

const TheAccountService = require('../lib/TheAccountService')
const {createDB} = require('./_helpers')
const {ok, equal} = require('assert')

describe('the-account-service', () => {
  before(() => {
  })

  after(() => {
  })

  it('Do test', async () => {
    const db = createDB()
    const {User} = db.resources
    const accountService = new TheAccountService(db.resources)
    ok(accountService)
    const user01 = await User.create({name: 'user01'})
    const image = 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAUCAYAAACNiR0NAAAAKElEQVQ4jWNgYGD4Twzu6FhFFGYYNXDUwGFpIAk2E4dHDRw1cDgaCAASFOffhEIO3gAAAABJRU5ErkJggg=='
    const {profile} = await accountService.processProfile({
      userId: user01.id,
      profileAttributes: {
        name: 'hoge',
        image
      },
      publicDir: `${__dirname}/../tmp/hoge/public`
    })
    equal(profile.name, 'hoge')

    const {sign} = await accountService.processPassword({
      userId: user01.id,
      newPassword: 'abc'
    })
    ok(sign.verifyPassword('abc'))
    ok(!sign.verifyPassword('___'))
  })
})

/* global describe, before, after, it */
