/**
 * Test for TheSignService.
 * Runs with mocha.
 */
'use strict'

const TheSignService = require('../lib/TheSignService')
const {createDB} = require('./_helpers')
const {ok, equal} = require('assert')

describe('the-sign-service', () => {
  before(() => {
  })

  after(() => {
  })

  it('Do test', async () => {
    const db = createDB()
    const signService = new TheSignService(db.resources)

    const {sign, user} = await signService.processSignUp({
      name: 'user01',
      password: 'pppp',
      profileAttributes: {name: 'User01'}
    })
    ok(user)
    ok(sign)

    ok(sign.verifyPassword('pppp'))

    await signService.processSignIn({
      name: 'user01',
      password: 'pppp'
    })

    await signService.processSignOut({
      userId: user.id
    })
  })

  it('Email duplication', async () => {
    const db = createDB()
    const signService = new TheSignService(db.resources)
    await signService.processSignUp({
      name: 'user01', password: 'pppp', profileAttributes: {email: 'a@example.com'}
    })
    try {
      await signService.processSignUp({
        name: 'user02', password: 'pppp', profileAttributes: {email: 'a@example.com'}
      })
    } catch (e) {
      ok(e.detail.conflict['profile.email'])
    }
  })
})

/* global describe, before, after, it */
