/**
 * Test for TheUserService.
 * Runs with mocha.
 */
'use strict'

const TheUserService = require('../lib/TheUserService')
const {createDB} = require('./_helpers')
const {ok, equal} = require('assert')

describe('the-user-service', () => {
  before(() => {
  })

  after(() => {
  })

  it('Do test', async () => {
    const db = createDB()
    const userService = new TheUserService(db.resources)
    const {user} = await userService.processCreate({
      name: 'hoge',
      roleCode: 'ADMIN',
      profileAttributes: {name: 'This is hoge'}
    })
    ok(user)
    equal(user.name, 'hoge')
    equal(user.profile.name, 'This is hoge')
    equal(user.displayName, 'This is hoge')

    const {newPasswords} = await userService.processReset({
      userIds: [user.id]
    })
    ok(newPasswords)

    const {newRoles} = await userService.processRole({
      userIds: [user.id],
      roleCode: 'NORMAL'
    })
    equal(newRoles[user.id], 'NORMAL')

    await user.sync()

    equal(user.role.code, 'NORMAL')

    await userService.processDestroy({
      userIds: [user.id]
    })
  })
})

/* global describe, before, after, it */
